@@ -1061,7 +1061,7 @@ bool CSSParser::parseValue( int propId, bool important )
             valid_primitive = true;
         break;
     case CSS_PROP__KHTML_USER_SELECT: // auto | none | text
-        if (id == CSS_VAL_AUTO || id == CSS_VAL_NONE || id == CSS_VAL_TEXT)
+        if (id == CSS_VAL_AUTO || id == CSS_VAL_NONE || id == CSS_VAL_TEXT || id == CSS_VAL_ELEMENT)
             valid_primitive = true;
         break;
     case CSS_PROP_TEXT_OVERFLOW: // clip | ellipsis
