@@ -152,11 +152,12 @@ typedef union {
     int element;
     CSSSelector::Relation relation;
     bool b;
+    int i;
     char tok;
     Value value;
     ValueList *valueList;
 } YYSTYPE;
-#line 105 "parser.y"
+#line 106 "parser.y"
 
 
 static inline int cssyyerror(const char *x ) {
@@ -305,23 +306,23 @@ static const short yyrhs[] = {    69,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   237,   239,   240,   241,   244,   251,   257,   282,   284,   287,
-   289,   290,   293,   295,   300,   301,   304,   306,   316,   318,
-   321,   323,   333,   335,   336,   337,   338,   339,   340,   343,
-   356,   359,   364,   373,   374,   377,   379,   382,   384,   387,
-   391,   395,   399,   403,   408,   414,   428,   430,   439,   461,
-   465,   470,   474,   479,   481,   482,   485,   487,   490,   509,
-   521,   535,   541,   545,   574,   580,   582,   583,   586,   591,
-   596,   601,   608,   617,   628,   645,   650,   654,   664,   670,
-   680,   681,   682,   685,   697,   717,   723,   729,   737,   748,
-   752,   755,   758,   761,   764,   769,   771,   774,   788,   795,
-   804,   808,   813,   816,   822,   830,   834,   837,   843,   849,
-   854,   860,   868,   891,   895,   903,   908,   915,   922,   924,
-   927,   932,   945,   951,   955,   958,   963,   965,   966,   967,
-   974,   975,   976,   977,   978,   979,   981,   986,   988,   989,
-   990,   991,   992,   993,   994,   995,   996,   997,   998,   999,
-  1000,  1001,  1002,  1003,  1004,  1008,  1016,  1031,  1038,  1045,
-  1053,  1063,  1089,  1091,  1094,  1096
+   238,   240,   241,   242,   245,   252,   258,   283,   285,   288,
+   290,   291,   294,   296,   301,   302,   305,   307,   317,   319,
+   322,   324,   334,   336,   337,   338,   339,   340,   341,   344,
+   357,   360,   365,   374,   375,   378,   380,   383,   385,   388,
+   392,   396,   400,   404,   409,   415,   429,   431,   440,   462,
+   466,   471,   475,   480,   482,   483,   486,   488,   491,   510,
+   522,   536,   542,   546,   575,   581,   583,   584,   587,   592,
+   597,   602,   609,   618,   629,   646,   651,   655,   665,   671,
+   681,   682,   683,   686,   698,   718,   724,   730,   738,   749,
+   753,   756,   759,   762,   765,   770,   772,   775,   789,   796,
+   805,   809,   814,   817,   823,   831,   835,   838,   844,   850,
+   855,   861,   869,   892,   896,   904,   909,   916,   923,   925,
+   928,   933,   946,   952,   956,   959,   964,   966,   967,   968,
+   975,   976,   977,   978,   979,   980,   982,   987,   989,   990,
+   991,   992,   993,   994,   995,   996,   997,   998,   999,  1000,
+  1001,  1002,  1003,  1004,  1005,  1009,  1017,  1032,  1039,  1046,
+  1054,  1064,  1090,  1092,  1095,  1097
 };
 #endif
 
@@ -1162,20 +1163,20 @@ yyreduce:
   switch (yyn) {
 
 case 5:
-#line 245 "parser.y"
+#line 246 "parser.y"
 {
         CSSParser *p = static_cast<CSSParser *>(parser);
         p->rule = yyvsp[-2].rule;
     ;
     break;}
 case 6:
-#line 252 "parser.y"
+#line 253 "parser.y"
 {
 	/* can be empty */
     ;
     break;}
 case 7:
-#line 258 "parser.y"
+#line 259 "parser.y"
 {
 	CSSParser *p = static_cast<CSSParser *>(parser);
 	if ( yyvsp[-1].valueList ) {
@@ -1200,7 +1201,7 @@ case 7:
     ;
     break;}
 case 14:
-#line 295 "parser.y"
+#line 296 "parser.y"
 {
 #ifdef CSS_DEBUG
      kdDebug( 6080 ) << "charset rule: " << qString(yyvsp[-2].string) << endl;
@@ -1208,7 +1209,7 @@ case 14:
  ;
     break;}
 case 18:
-#line 306 "parser.y"
+#line 307 "parser.y"
 {
      CSSParser *p = static_cast<CSSParser *>(parser);
      if ( yyvsp[-1].rule && p->styleElement && p->styleElement->isCSSStyleSheet() ) {
@@ -1219,7 +1220,7 @@ case 18:
  ;
     break;}
 case 22:
-#line 323 "parser.y"
+#line 324 "parser.y"
 {
      CSSParser *p = static_cast<CSSParser *>(parser);
      if ( yyvsp[-1].rule && p->styleElement && p->styleElement->isCSSStyleSheet() ) {
@@ -1230,7 +1231,7 @@ case 22:
  ;
     break;}
 case 30:
-#line 344 "parser.y"
+#line 345 "parser.y"
 {
 #ifdef CSS_DEBUG
 	kdDebug( 6080 ) << "@import: " << qString(yyvsp[-3].string) << endl;
@@ -1245,19 +1246,19 @@ case 30:
     ;
     break;}
 case 31:
-#line 356 "parser.y"
+#line 357 "parser.y"
 {
         yyval.rule = 0;
     ;
     break;}
 case 32:
-#line 359 "parser.y"
+#line 360 "parser.y"
 {
         yyval.rule = 0;
     ;
     break;}
 case 33:
-#line 365 "parser.y"
+#line 366 "parser.y"
 {
 #ifdef CSS_DEBUG
     kdDebug( 6080 ) << "@namespace: " << qString(yyvsp[-2].string) << endl;
@@ -1268,34 +1269,34 @@ case 33:
 ;
     break;}
 case 36:
-#line 378 "parser.y"
+#line 379 "parser.y"
 { yyval.string.string = 0; ;
     break;}
 case 37:
-#line 379 "parser.y"
+#line 380 "parser.y"
 { yyval.string = yyvsp[-1].string; ;
     break;}
 case 40:
-#line 388 "parser.y"
+#line 389 "parser.y"
 {
         yyval.mediaList = new MediaListImpl();
      ;
     break;}
 case 42:
-#line 396 "parser.y"
+#line 397 "parser.y"
 {
 	yyval.mediaList = 0;
     ;
     break;}
 case 43:
-#line 399 "parser.y"
+#line 400 "parser.y"
 {
 	yyval.mediaList = new MediaListImpl();
 	yyval.mediaList->appendMedium( domString(yyvsp[0].string).lower() );
     ;
     break;}
 case 44:
-#line 403 "parser.y"
+#line 404 "parser.y"
 {
 	yyval.mediaList = yyvsp[-3].mediaList;
         if (yyval.mediaList)
@@ -1303,14 +1304,14 @@ case 44:
     ;
     break;}
 case 45:
-#line 408 "parser.y"
+#line 409 "parser.y"
 {
         delete yyvsp[-1].mediaList;
         yyval.mediaList = 0;
     ;
     break;}
 case 46:
-#line 415 "parser.y"
+#line 416 "parser.y"
 {
 	CSSParser *p = static_cast<CSSParser *>(parser);
 	if ( yyvsp[-4].mediaList && yyvsp[-1].ruleList &&
@@ -1324,11 +1325,11 @@ case 46:
     ;
     break;}
 case 47:
-#line 429 "parser.y"
+#line 430 "parser.y"
 { yyval.ruleList = 0; ;
     break;}
 case 48:
-#line 430 "parser.y"
+#line 431 "parser.y"
 {
       yyval.ruleList = yyvsp[-2].ruleList;
       if ( yyvsp[-1].rule ) {
@@ -1338,57 +1339,57 @@ case 48:
   ;
     break;}
 case 49:
-#line 440 "parser.y"
+#line 441 "parser.y"
 {
       yyval.string = yyvsp[-1].string;
   ;
     break;}
 case 50:
-#line 462 "parser.y"
+#line 463 "parser.y"
 {
       yyval.rule = 0;
     ;
     break;}
 case 51:
-#line 465 "parser.y"
+#line 466 "parser.y"
 {
       yyval.rule = 0;
     ;
     break;}
 case 52:
-#line 471 "parser.y"
+#line 472 "parser.y"
 {
       yyval.rule = 0;
     ;
     break;}
 case 53:
-#line 474 "parser.y"
+#line 475 "parser.y"
 {
       yyval.rule = 0;
     ;
     break;}
 case 54:
-#line 480 "parser.y"
+#line 481 "parser.y"
 { yyval.relation = CSSSelector::Sibling; ;
     break;}
 case 55:
-#line 481 "parser.y"
+#line 482 "parser.y"
 { yyval.relation = CSSSelector::Child; ;
     break;}
 case 56:
-#line 482 "parser.y"
+#line 483 "parser.y"
 { yyval.relation = CSSSelector::Descendant; ;
     break;}
 case 57:
-#line 486 "parser.y"
-{ yyval.val = -1; ;
+#line 487 "parser.y"
+{ yyval.i = -1; ;
     break;}
 case 58:
-#line 487 "parser.y"
-{ yyval.val = 1; ;
+#line 488 "parser.y"
+{ yyval.i = 1; ;
     break;}
 case 59:
-#line 491 "parser.y"
+#line 492 "parser.y"
 {
 #ifdef CSS_DEBUG
 	kdDebug( 6080 ) << "got ruleset" << endl << "  selector:" << endl;
@@ -1407,7 +1408,7 @@ case 59:
     ;
     break;}
 case 60:
-#line 510 "parser.y"
+#line 511 "parser.y"
 {
 	if ( yyvsp[0].selector ) {
 	    yyval.selector = yyvsp[0].selector;
@@ -1421,7 +1422,7 @@ case 60:
     ;
     break;}
 case 61:
-#line 521 "parser.y"
+#line 522 "parser.y"
 {
 	if ( yyvsp[-3].selector && yyvsp[0].selector ) {
 	    yyval.selector = yyvsp[-3].selector;
@@ -1438,20 +1439,20 @@ case 61:
     ;
     break;}
 case 62:
-#line 535 "parser.y"
+#line 536 "parser.y"
 {
         delete yyvsp[-1].selector;
         yyval.selector = 0;
     ;
     break;}
 case 63:
-#line 542 "parser.y"
+#line 543 "parser.y"
 {
 	yyval.selector = yyvsp[0].selector;
     ;
     break;}
 case 64:
-#line 545 "parser.y"
+#line 546 "parser.y"
 {
     	yyval.selector = yyvsp[0].selector;
         if (!yyvsp[-2].selector) {
@@ -1483,33 +1484,33 @@ case 64:
     ;
     break;}
 case 65:
-#line 574 "parser.y"
+#line 575 "parser.y"
 {
         delete yyvsp[-1].selector;
         yyval.selector = 0;
     ;
     break;}
 case 66:
-#line 581 "parser.y"
+#line 582 "parser.y"
 { yyval.string.string = 0; yyval.string.length = 0; ;
     break;}
 case 67:
-#line 582 "parser.y"
+#line 583 "parser.y"
 { static unsigned short star = '*'; yyval.string.string = &star; yyval.string.length = 1; ;
     break;}
 case 68:
-#line 583 "parser.y"
+#line 584 "parser.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 69:
-#line 587 "parser.y"
+#line 588 "parser.y"
 {
 	yyval.selector = new CSSSelector();
 	yyval.selector->tag = yyvsp[-1].element;
     ;
     break;}
 case 70:
-#line 591 "parser.y"
+#line 592 "parser.y"
 {
 	yyval.selector = yyvsp[-1].selector;
 	if ( yyval.selector )
@@ -1517,7 +1518,7 @@ case 70:
     ;
     break;}
 case 71:
-#line 596 "parser.y"
+#line 597 "parser.y"
 {
 	yyval.selector = yyvsp[-1].selector;
         if (yyval.selector)
@@ -1525,7 +1526,7 @@ case 71:
     ;
     break;}
 case 72:
-#line 601 "parser.y"
+#line 602 "parser.y"
 {
         yyval.selector = new CSSSelector();
         yyval.selector->tag = yyvsp[-1].element;
@@ -1535,7 +1536,7 @@ case 72:
     ;
     break;}
 case 73:
-#line 608 "parser.y"
+#line 609 "parser.y"
 {
         yyval.selector = yyvsp[-1].selector;
         if (yyval.selector) {
@@ -1547,7 +1548,7 @@ case 73:
     ;
     break;}
 case 74:
-#line 617 "parser.y"
+#line 618 "parser.y"
 {
         yyval.selector = yyvsp[-1].selector;
         if (yyval.selector) {
@@ -1559,7 +1560,7 @@ case 74:
     ;
     break;}
 case 75:
-#line 629 "parser.y"
+#line 630 "parser.y"
 {
 	CSSParser *p = static_cast<CSSParser *>(parser);
 	DOM::DocumentImpl *doc = p->document();
@@ -1578,19 +1579,19 @@ case 75:
     ;
     break;}
 case 76:
-#line 645 "parser.y"
+#line 646 "parser.y"
 {
 	yyval.element = makeId(static_cast<CSSParser*>(parser)->defaultNamespace, anyLocalName);
     ;
     break;}
 case 77:
-#line 651 "parser.y"
+#line 652 "parser.y"
 {
 	yyval.selector = yyvsp[0].selector;
     ;
     break;}
 case 78:
-#line 654 "parser.y"
+#line 655 "parser.y"
 {
 	yyval.selector = yyvsp[-1].selector;
         if (yyval.selector) {
@@ -1603,14 +1604,14 @@ case 78:
     ;
     break;}
 case 79:
-#line 664 "parser.y"
+#line 665 "parser.y"
 {
         delete yyvsp[-1].selector;
         yyval.selector = 0;
     ;
     break;}
 case 80:
-#line 671 "parser.y"
+#line 672 "parser.y"
 {
 	yyval.selector = new CSSSelector();
 	yyval.selector->match = CSSSelector::Id;
@@ -1622,7 +1623,7 @@ case 80:
     ;
     break;}
 case 84:
-#line 686 "parser.y"
+#line 687 "parser.y"
 {
         yyval.selector = new CSSSelector();
 	yyval.selector->match = CSSSelector::Class;
@@ -1634,7 +1635,7 @@ case 84:
     ;
     break;}
 case 85:
-#line 698 "parser.y"
+#line 699 "parser.y"
 {
 	CSSParser *p = static_cast<CSSParser *>(parser);
 	DOM::DocumentImpl *doc = p->document();
@@ -1654,7 +1655,7 @@ case 85:
     ;
     break;}
 case 86:
-#line 718 "parser.y"
+#line 719 "parser.y"
 {
 	yyval.selector = new CSSSelector();
 	yyval.selector->attr = yyvsp[-1].attribute;
@@ -1662,16 +1663,16 @@ case 86:
     ;
     break;}
 case 87:
-#line 723 "parser.y"
+#line 724 "parser.y"
 {
 	yyval.selector = new CSSSelector();
 	yyval.selector->attr = yyvsp[-5].attribute;
-	yyval.selector->match = (CSSSelector::Match)yyvsp[-4].val;
+	yyval.selector->match = (CSSSelector::Match)yyvsp[-4].i;
 	yyval.selector->value = atomicString(yyvsp[-2].string);
     ;
     break;}
 case 88:
-#line 729 "parser.y"
+#line 730 "parser.y"
 {
         yyval.selector = new CSSSelector();
         yyval.selector->attr = yyvsp[-1].attribute;
@@ -1682,11 +1683,11 @@ case 88:
     ;
     break;}
 case 89:
-#line 737 "parser.y"
+#line 738 "parser.y"
 {
         yyval.selector = new CSSSelector();
         yyval.selector->attr = yyvsp[-5].attribute;
-        yyval.selector->match = (CSSSelector::Match)yyvsp[-4].val;
+        yyval.selector->match = (CSSSelector::Match)yyvsp[-4].i;
         yyval.selector->value = atomicString(yyvsp[-2].string);
         CSSParser *p = static_cast<CSSParser *>(parser);
         if (p->styleElement && p->styleElement->isCSSStyleSheet())
@@ -1694,43 +1695,43 @@ case 89:
     ;
     break;}
 case 90:
-#line 749 "parser.y"
+#line 750 "parser.y"
 {
-	yyval.val = CSSSelector::Exact;
+	yyval.i = CSSSelector::Exact;
     ;
     break;}
 case 91:
-#line 752 "parser.y"
+#line 753 "parser.y"
 {
-	yyval.val = CSSSelector::List;
+	yyval.i = CSSSelector::List;
     ;
     break;}
 case 92:
-#line 755 "parser.y"
+#line 756 "parser.y"
 {
-	yyval.val = CSSSelector::Hyphen;
+	yyval.i = CSSSelector::Hyphen;
     ;
     break;}
 case 93:
-#line 758 "parser.y"
+#line 759 "parser.y"
 {
-	yyval.val = CSSSelector::Begin;
+	yyval.i = CSSSelector::Begin;
     ;
     break;}
 case 94:
-#line 761 "parser.y"
+#line 762 "parser.y"
 {
-	yyval.val = CSSSelector::End;
+	yyval.i = CSSSelector::End;
     ;
     break;}
 case 95:
-#line 764 "parser.y"
+#line 765 "parser.y"
 {
-	yyval.val = CSSSelector::Contain;
+	yyval.i = CSSSelector::Contain;
     ;
     break;}
 case 98:
-#line 775 "parser.y"
+#line 776 "parser.y"
 {
         yyval.selector = new CSSSelector();
         yyval.selector->match = CSSSelector::Pseudo;
@@ -1746,7 +1747,7 @@ case 98:
     ;
     break;}
 case 99:
-#line 789 "parser.y"
+#line 790 "parser.y"
 {
         yyval.selector = new CSSSelector();
         yyval.selector->match = CSSSelector::Pseudo;
@@ -1755,7 +1756,7 @@ case 99:
     ;
     break;}
 case 100:
-#line 795 "parser.y"
+#line 796 "parser.y"
 {
         yyval.selector = new CSSSelector();
         yyval.selector->match = CSSSelector::Pseudo;
@@ -1765,13 +1766,13 @@ case 100:
     ;
     break;}
 case 101:
-#line 805 "parser.y"
+#line 806 "parser.y"
 {
 	yyval.ok = yyvsp[0].ok;
     ;
     break;}
 case 102:
-#line 808 "parser.y"
+#line 809 "parser.y"
 {
 	yyval.ok = yyvsp[-1].ok;
 	if ( yyvsp[0].ok )
@@ -1779,13 +1780,13 @@ case 102:
     ;
     break;}
 case 103:
-#line 813 "parser.y"
+#line 814 "parser.y"
 {
 	yyval.ok = yyvsp[0].ok;
     ;
     break;}
 case 104:
-#line 816 "parser.y"
+#line 817 "parser.y"
 {
 	yyval.ok = false;
 #ifdef CSS_DEBUG
@@ -1794,7 +1795,7 @@ case 104:
     ;
     break;}
 case 105:
-#line 822 "parser.y"
+#line 823 "parser.y"
 {
 	yyval.ok = false;
 #ifdef CSS_DEBUG
@@ -1803,19 +1804,19 @@ case 105:
     ;
     break;}
 case 106:
-#line 831 "parser.y"
+#line 832 "parser.y"
 {
 	yyval.ok = yyvsp[-2].ok;
     ;
     break;}
 case 107:
-#line 834 "parser.y"
+#line 835 "parser.y"
 {
         yyval.ok = false;
     ;
     break;}
 case 108:
-#line 837 "parser.y"
+#line 838 "parser.y"
 {
 	yyval.ok = false;
 #ifdef CSS_DEBUG
@@ -1824,7 +1825,7 @@ case 108:
     ;
     break;}
 case 109:
-#line 843 "parser.y"
+#line 844 "parser.y"
 {
 	yyval.ok = false;
 #ifdef CSS_DEBUG
@@ -1833,7 +1834,7 @@ case 109:
     ;
     break;}
 case 110:
-#line 849 "parser.y"
+#line 850 "parser.y"
 {
 	yyval.ok = yyvsp[-3].ok;
 	if ( yyvsp[-2].ok )
@@ -1841,7 +1842,7 @@ case 110:
     ;
     break;}
 case 111:
-#line 854 "parser.y"
+#line 855 "parser.y"
 {
 	yyval.ok = yyvsp[-3].ok;
 #ifdef CSS_DEBUG
@@ -1850,7 +1851,7 @@ case 111:
     ;
     break;}
 case 112:
-#line 860 "parser.y"
+#line 861 "parser.y"
 {
 	yyval.ok = yyvsp[-5].ok;
 #ifdef CSS_DEBUG
@@ -1859,7 +1860,7 @@ case 112:
     ;
     break;}
 case 113:
-#line 869 "parser.y"
+#line 870 "parser.y"
 {
 	yyval.ok = false;
 	CSSParser *p = static_cast<CSSParser *>(parser);
@@ -1884,13 +1885,13 @@ case 113:
     ;
     break;}
 case 114:
-#line 892 "parser.y"
+#line 893 "parser.y"
 {
         yyval.ok = false;
     ;
     break;}
 case 115:
-#line 896 "parser.y"
+#line 897 "parser.y"
 {
         /* The default movable type template has letter-spacing: .none;  Handle this by looking for
         error tokens at the start of an expr, recover the expr and then treat as an error, cleaning
@@ -1900,43 +1901,43 @@ case 115:
     ;
     break;}
 case 116:
-#line 904 "parser.y"
+#line 905 "parser.y"
 {
         /* Handle this case: div { text-align: center; !important } Just reduce away the stray !important. */
         yyval.ok = false;
     ;
     break;}
 case 117:
-#line 909 "parser.y"
+#line 910 "parser.y"
 {
         /* div { font-family: } Just reduce away this property with no value. */
         yyval.ok = false;
     ;
     break;}
 case 118:
-#line 916 "parser.y"
+#line 917 "parser.y"
 {
 	QString str = qString(yyvsp[-1].string);
 	yyval.prop_id = getPropertyID( str.lower().latin1(), str.length() );
     ;
     break;}
 case 119:
-#line 923 "parser.y"
+#line 924 "parser.y"
 { yyval.b = true; ;
     break;}
 case 120:
-#line 924 "parser.y"
+#line 925 "parser.y"
 { yyval.b = false; ;
     break;}
 case 121:
-#line 928 "parser.y"
+#line 929 "parser.y"
 {
 	yyval.valueList = new ValueList;
 	yyval.valueList->addValue( yyvsp[0].value );
     ;
     break;}
 case 122:
-#line 932 "parser.y"
+#line 933 "parser.y"
 {
         yyval.valueList = yyvsp[-2].valueList;
 	if ( yyval.valueList ) {
@@ -1952,44 +1953,44 @@ case 122:
     ;
     break;}
 case 123:
-#line 945 "parser.y"
+#line 946 "parser.y"
 {
         delete yyvsp[-1].valueList;
         yyval.valueList = 0;
     ;
     break;}
 case 124:
-#line 952 "parser.y"
+#line 953 "parser.y"
 {
 	yyval.tok = '/';
     ;
     break;}
 case 125:
-#line 955 "parser.y"
+#line 956 "parser.y"
 {
 	yyval.tok = ',';
     ;
     break;}
 case 126:
-#line 958 "parser.y"
+#line 959 "parser.y"
 {
         yyval.tok = 0;
   ;
     break;}
 case 127:
-#line 964 "parser.y"
+#line 965 "parser.y"
 { yyval.value = yyvsp[0].value; ;
     break;}
 case 128:
-#line 965 "parser.y"
-{ yyval.value = yyvsp[0].value; yyval.value.fValue *= yyvsp[-1].val; ;
+#line 966 "parser.y"
+{ yyval.value = yyvsp[0].value; yyval.value.fValue *= yyvsp[-1].i; ;
     break;}
 case 129:
-#line 966 "parser.y"
+#line 967 "parser.y"
 { yyval.value.id = 0; yyval.value.string = yyvsp[-1].string; yyval.value.unit = CSSPrimitiveValue::CSS_STRING; ;
     break;}
 case 130:
-#line 967 "parser.y"
+#line 968 "parser.y"
 {
       QString str = qString( yyvsp[-1].string );
       yyval.value.id = getValueID( str.lower().latin1(), str.length() );
@@ -1998,109 +1999,109 @@ case 130:
   ;
     break;}
 case 131:
-#line 974 "parser.y"
-{ yyval.value.id = 0; yyval.value.string = yyvsp[-1].string; yyval.value.unit = CSSPrimitiveValue::CSS_DIMENSION ;
-    break;}
-case 132:
 #line 975 "parser.y"
 { yyval.value.id = 0; yyval.value.string = yyvsp[-1].string; yyval.value.unit = CSSPrimitiveValue::CSS_DIMENSION ;
     break;}
-case 133:
+case 132:
 #line 976 "parser.y"
+{ yyval.value.id = 0; yyval.value.string = yyvsp[-1].string; yyval.value.unit = CSSPrimitiveValue::CSS_DIMENSION ;
+    break;}
+case 133:
+#line 977 "parser.y"
 { yyval.value.id = 0; yyval.value.string = yyvsp[-1].string; yyval.value.unit = CSSPrimitiveValue::CSS_URI; ;
     break;}
 case 134:
-#line 977 "parser.y"
+#line 978 "parser.y"
 { yyval.value.id = 0; yyval.value.iValue = 0; yyval.value.unit = CSSPrimitiveValue::CSS_UNKNOWN;/* ### */ ;
     break;}
 case 135:
-#line 978 "parser.y"
+#line 979 "parser.y"
 { yyval.value.id = 0; yyval.value.string = yyvsp[0].string; yyval.value.unit = CSSPrimitiveValue::CSS_RGBCOLOR; ;
     break;}
 case 136:
-#line 979 "parser.y"
+#line 980 "parser.y"
 { yyval.value.id = 0; yyval.value.string = ParseString(); yyval.value.unit = CSSPrimitiveValue::CSS_RGBCOLOR; ;
     break;}
 case 137:
-#line 981 "parser.y"
+#line 982 "parser.y"
 {
       yyval.value = yyvsp[0].value;
   ;
     break;}
 case 138:
-#line 987 "parser.y"
+#line 988 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_NUMBER; ;
     break;}
 case 139:
-#line 988 "parser.y"
+#line 989 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_PERCENTAGE; ;
     break;}
 case 140:
-#line 989 "parser.y"
+#line 990 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_PX; ;
     break;}
 case 141:
-#line 990 "parser.y"
+#line 991 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_CM; ;
     break;}
 case 142:
-#line 991 "parser.y"
+#line 992 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_MM; ;
     break;}
 case 143:
-#line 992 "parser.y"
+#line 993 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_IN; ;
     break;}
 case 144:
-#line 993 "parser.y"
+#line 994 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_PT; ;
     break;}
 case 145:
-#line 994 "parser.y"
+#line 995 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_PC; ;
     break;}
 case 146:
-#line 995 "parser.y"
+#line 996 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_DEG; ;
     break;}
 case 147:
-#line 996 "parser.y"
+#line 997 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_RAD; ;
     break;}
 case 148:
-#line 997 "parser.y"
+#line 998 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_GRAD; ;
     break;}
 case 149:
-#line 998 "parser.y"
+#line 999 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_MS; ;
     break;}
 case 150:
-#line 999 "parser.y"
+#line 1000 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_S; ;
     break;}
 case 151:
-#line 1000 "parser.y"
+#line 1001 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_HZ; ;
     break;}
 case 152:
-#line 1001 "parser.y"
+#line 1002 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_KHZ; ;
     break;}
 case 153:
-#line 1002 "parser.y"
+#line 1003 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_EMS; ;
     break;}
 case 154:
-#line 1003 "parser.y"
+#line 1004 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = Value::Q_EMS; ;
     break;}
 case 155:
-#line 1004 "parser.y"
+#line 1005 "parser.y"
 { yyval.value.id = 0; yyval.value.fValue = yyvsp[-1].val; yyval.value.unit = CSSPrimitiveValue::CSS_EXS; ;
     break;}
 case 156:
-#line 1009 "parser.y"
+#line 1010 "parser.y"
 {
       Function *f = new Function;
       f->name = yyvsp[-4].string;
@@ -2111,7 +2112,7 @@ case 156:
   ;
     break;}
 case 157:
-#line 1017 "parser.y"
+#line 1018 "parser.y"
 {
       Function *f = new Function;
       f->name = yyvsp[-2].string;
@@ -2122,11 +2123,11 @@ case 157:
   ;
     break;}
 case 158:
-#line 1032 "parser.y"
+#line 1033 "parser.y"
 { yyval.string = yyvsp[-1].string; ;
     break;}
 case 159:
-#line 1039 "parser.y"
+#line 1040 "parser.y"
 {
 	yyval.rule = 0;
 #ifdef CSS_DEBUG
@@ -2135,7 +2136,7 @@ case 159:
     ;
     break;}
 case 160:
-#line 1045 "parser.y"
+#line 1046 "parser.y"
 {
 	yyval.rule = 0;
 #ifdef CSS_DEBUG
@@ -2144,7 +2145,7 @@ case 160:
     ;
     break;}
 case 161:
-#line 1054 "parser.y"
+#line 1055 "parser.y"
 {
         delete yyvsp[0].rule;
         yyval.rule = 0;
@@ -2154,7 +2155,7 @@ case 161:
     ;
     break;}
 case 162:
-#line 1064 "parser.y"
+#line 1065 "parser.y"
 {
 	yyval.rule = 0;
 #ifdef CSS_DEBUG
@@ -2384,6 +2385,6 @@ yyerrhandle:
     }
   return 1;
 }
-#line 1099 "parser.y"
+#line 1100 "parser.y"
 
 
