@@ -70,7 +70,8 @@ void HTMLImageLoader::updateFromElement()
 {
     // If we're not making renderers for the page, then don't load images.  We don't want to slow
     // down the raw HTML parsing case by loading images we don't intend to display.
-    if (!element()->getDocument()->renderer())
+    DocumentImpl* document = element()->getDocument();
+    if (!document || !document->renderer())
         return;
 
     AtomicString attr;
