@@ -389,6 +389,7 @@ HTMLObjectElementImpl::HTMLObjectElementImpl(DocumentPtr *doc)
 {
     needWidgetUpdate = false;
     m_useFallbackContent = false;
+    m_complete = false;
 }
 
 HTMLObjectElementImpl::~HTMLObjectElementImpl()
@@ -557,7 +558,6 @@ void HTMLObjectElementImpl::attach()
                 // this method or recalcStyle (which also calls updateWidget) to be called.
                 needWidgetUpdate = false;
                 static_cast<RenderPartObject*>(m_render)->updateWidget();
-                dispatchHTMLEvent(EventImpl::LOAD_EVENT,false,false);
             } else {
                 needWidgetUpdate = true;
                 setChanged();
@@ -566,14 +566,33 @@ void HTMLObjectElementImpl::attach()
     }
 }
 
+void HTMLObjectElementImpl::closeRenderer()
+{
+    // The parser just reached </object>.
+    setComplete(true);
+    
+    HTMLElementImpl::closeRenderer();
+}
+
+void HTMLObjectElementImpl::setComplete(bool complete)
+{
+    if (complete != m_complete) {
+        m_complete = complete;
+        if (complete && inDocument() && !m_useFallbackContent) {
+            needWidgetUpdate = true;
+            setChanged();
+        }
+    }
+}
+
 void HTMLObjectElementImpl::detach()
 {
-    // Only bother with an unload event if we had a render object.  - dwh
-    if (attached() && m_render && !m_useFallbackContent)
-        // ### do this when we are actualy removed from document instead
-        dispatchHTMLEvent(EventImpl::UNLOAD_EVENT,false,false);
+    if (attached() && m_render && !m_useFallbackContent) {
+        // Update the widget the next time we attach (detaching destroys the plugin).
+        needWidgetUpdate = true;
+    }
 
-  HTMLElementImpl::detach();
+    HTMLElementImpl::detach();
 }
 
 void HTMLObjectElementImpl::recalcStyle(StyleChange ch)
