@@ -129,6 +129,7 @@ public:
 
     virtual const char *renderName() const { return "RenderButton"; }
     virtual short baselinePosition( bool, bool ) const;
+    virtual void calcMinMaxWidth();
 
     // don't even think about making this method virtual!
     DOM::HTMLInputElementImpl* element() const
@@ -243,7 +244,13 @@ public:
     virtual void updateFromElement();
     virtual void setStyle(RenderStyle *);
 
+    long selectionStart();
+    long selectionEnd();
+    void setSelectionStart(long);
+    void setSelectionEnd(long);
+    
     void select();
+    void setSelectionRange(long, long);
 
     KLineEdit *widget() const { return static_cast<KLineEdit*>(m_widget); }
     DOM::HTMLInputElementImpl* element() const
@@ -463,8 +470,14 @@ public:
 
     QString text();
 
+    long selectionStart();
+    long selectionEnd();
+    void setSelectionStart(long);
+    void setSelectionEnd(long);
+    
     void select();
-
+    void setSelectionRange(long, long);
+    
 #if APPLE_CHANGES
     virtual bool canHaveIntrinsicMargins() const { return true; }
 #endif
