@@ -158,6 +158,32 @@ private:
 class RenderLayer
 {
 public:
+    enum ScrollBehavior {
+        noScroll,
+        alignCenter,
+        alignTop,
+        alignBottom, 
+        alignLeft,
+        alignRight,
+        alignToClosestEdge
+    };
+
+    struct ScrollAlignment {
+        ScrollBehavior m_rectVisible;
+        ScrollBehavior m_rectHidden;
+        ScrollBehavior m_rectPartial;
+    };
+
+    static const ScrollAlignment gAlignCenterIfNeeded;
+    static const ScrollAlignment gAlignToEdgeIfNeeded;
+    static const ScrollAlignment gAlignCenterAlways;
+    static const ScrollAlignment gAlignTopAlways;
+    static const ScrollAlignment gAlignBottomAlways;
+    
+    static ScrollBehavior getVisibleBehavior(const ScrollAlignment& s) { return s.m_rectVisible; }
+    static ScrollBehavior getPartialBehavior(const ScrollAlignment& s) { return s.m_rectPartial; }
+    static ScrollBehavior getHiddenBehavior(const ScrollAlignment& s) { return s.m_rectHidden; }
+    
 #ifdef APPLE_CHANGES
     static QScrollBar* gScrollBar;
 #endif
@@ -222,6 +248,8 @@ public:
     void scrollToOffset(int x, int y, bool updateScrollbars = true, bool repaint = true);
     void scrollToXOffset(int x) { scrollToOffset(x, m_scrollY); }
     void scrollToYOffset(int y) { scrollToOffset(m_scrollX, y); }
+    void scrollRectToVisible(const QRect &r, const ScrollAlignment& alignX = gAlignCenterIfNeeded, const ScrollAlignment& alignY = gAlignCenterIfNeeded);
+    QRect getRectToExpose(const QRect &visibleRect,  const QRect &exposeRect, const ScrollAlignment& alignX, const ScrollAlignment& alignY);   
     void setHasHorizontalScrollbar(bool hasScrollbar);
     void setHasVerticalScrollbar(bool hasScrollbar);
     QScrollBar* horizontalScrollbar() { return m_hBar; }
