@@ -149,7 +149,6 @@ m_isText( false ),
 m_inline( true ),
 
 m_replaced( false ),
-m_mouseInside( false ),
 m_isDragging( false ),
 m_hasOverflowClip(false)
 {
@@ -509,7 +508,7 @@ RenderLayer* RenderObject::enclosingLayer()
 bool RenderObject::requiresLayer()
 {
     return isRoot() || isPositioned() || isRelPositioned() || style()->opacity() < 1.0f ||
-           m_hasOverflowClip;
+           hasOverflowClip();
 }
 
 RenderBlock* RenderObject::firstLineBlock() const
@@ -1321,7 +1320,6 @@ QString RenderObject::information() const
     if (isPositioned()) ts << "ps ";
     if (needsLayout()) ts << "nl ";
     if (m_recalcMinMax) ts << "rmm ";
-    if (mouseInside()) ts << "mi ";
     if (style() && style()->zIndex()) ts << "zI: " << style()->zIndex();
     if (element() && element()->active()) ts << "act ";
     if (element() && element()->hasAnchor()) ts << "anchor ";
@@ -1878,13 +1876,6 @@ VisiblePosition RenderObject::positionForCoordinates(int x, int y)
     return VisiblePosition(element(), caretMinOffset(), DOWNSTREAM);
 }
 
-bool RenderObject::mouseInside() const
-{ 
-    if (!m_mouseInside && continuation()) 
-        return continuation()->mouseInside();
-    return m_mouseInside; 
-}
-
 bool RenderObject::isDragging() const
 { 
     return m_isDragging; 
