@@ -101,8 +101,7 @@ void RenderReplaced::calcMinMaxWidth()
     if (style()->width().isPercent() || (style()->width().isVariable() && style()->height().isPercent())) {
         m_minWidth = 0;
         m_maxWidth = width;
-    }
-    else
+    } else
         m_minWidth = m_maxWidth = width;
 
     setMinMaxKnown();
