@@ -43,8 +43,12 @@ class QTextEdit : public QScrollView
     } TextFormat;
 
     QTextEdit(QWidget *parent);
+    ~QTextEdit();
+
+    virtual void setPalette(const QPalette &);
 
     void setAlignment(AlignmentFlags);
+    void setLineHeight(int lineHeight);
 
     void setCursorPosition(int, int);
     void getCursorPosition(int *, int *) const;
@@ -66,9 +70,17 @@ class QTextEdit : public QScrollView
     void setWordWrap(WrapStyle);
     WrapStyle wordWrap() const;
 
+    void setScrollBarModes(ScrollBarMode hMode, ScrollBarMode vMode);
+
     void setWritingDirection(QPainter::TextDirection);
+
+    long selectionStart();
+    long selectionEnd();
+    void setSelectionStart(long);
+    void setSelectionEnd(long);
     
     void selectAll();
+    void setSelectionRange(long, long);
 
     QSize sizeWithColumnsAndRows(int numColumns, int numRows) const;
 
