@@ -47,6 +47,8 @@
 }
 
 + (WebCoreImageRendererFactory *)sharedFactory;
++ (BOOL)shouldUseThreadedDecoding;
++ (void)setShouldUseThreadedDecoding:(BOOL)flag;
 @end
 
 @interface WebCoreImageRendererFactory (SubclassResponsibility) <WebCoreImageRendererFactory>
